@@ -7,6 +7,9 @@ Pymatgen (Python Materials Genomics) is a robust, open-source Python library
 for materials analysis. This is the root package.
 """
 
+
+# Useful aliases for commonly used objects and modules.
+# Allows from pymatgen import <class> for quick usage.
 import os
 import warnings
 import ruamel.yaml as yaml
@@ -16,7 +19,7 @@ __author__ = "Pymatgen Development Team"
 __email__ = "pymatgen@googlegroups.com"
 __maintainer__ = "Shyue Ping Ong"
 __maintainer_email__ = "shyuep@gmail.com"
-__version__ = "2019.9.12"
+__version__ = "2019.9.16"
 
 SETTINGS_FILE = os.path.join(os.path.expanduser("~"), ".pmgrc.yaml")
 
@@ -39,10 +42,14 @@ def _load_pmg_settings():
 
 SETTINGS = _load_pmg_settings()
 
-# Useful aliases for commonly used objects and modules.
-# Allows from pymatgen import <class> for quick usage.
 
-from pymatgen.core import *
+from .core.periodic_table import Element, Specie, DummySpecie
+from .core.composition import Composition
+from .core.structure import Structure, IStructure, Molecule, IMolecule
+from .core.lattice import Lattice
+from .core.sites import Site, PeriodicSite
+from .core.operations import SymmOp
+from .core.units import Unit, FloatWithUnit, ArrayWithUnit
 from .electronic_structure.core import Spin, Orbital
 from .ext.matproj import MPRester
 from monty.json import MontyEncoder, MontyDecoder, MSONable
