@@ -2,10 +2,12 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
+"""
+Perform fragmentation of molecules.
+"""
 
 import logging
 import copy
-import numpy as np
 from monty.json import MSONable
 from pymatgen.analysis.graphs import MoleculeGraph, MolGraphSplitError
 from pymatgen.analysis.local_env import OpenBabelNN
@@ -23,6 +25,9 @@ logger = logging.getLogger(__name__)
 
 
 class Fragmenter(MSONable):
+    """
+    Molecule fragmenter class.
+    """
 
     def __init__(self, molecule, edges=None, depth=1, open_rings=False, use_metal_edge_extender=False,
                  opt_steps=10000, prev_unique_frag_dict=None, assume_previous_thoroughness=True):
@@ -169,7 +174,6 @@ class Fragmenter(MSONable):
                     try:
                         fragments = old_frag.split_molecule_subgraphs(bond, allow_reverse=True)
                     except MolGraphSplitError:
-                        ring_bond = True
                         if self.open_rings:
                             fragments = [open_ring(old_frag, bond, self.opt_steps)]
                     for fragment in fragments:
