@@ -2,6 +2,10 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
+"""
+This module implements input and output processing from Gaussian.
+"""
+
 import re
 
 import numpy as np
@@ -15,9 +19,6 @@ from pymatgen.util.coord import get_angle
 import scipy.constants as cst
 
 from pymatgen.electronic_structure.core import Spin
-"""
-This module implements input and output processing from Gaussian.
-"""
 
 __author__ = 'Shyue Ping Ong, Germain  Salvato-Vallverdu, Xin Chen'
 __copyright__ = 'Copyright 2013, The Materials Virtual Lab'
@@ -86,30 +87,6 @@ def read_route_line(route):
 class GaussianInput:
     """
     An object representing a Gaussian input file.
-
-    Args:
-        mol: Input molecule. If molecule is a single string, it is used as a
-            direct input to the geometry section of the Gaussian input
-            file.
-        charge: Charge of the molecule. If None, charge on molecule is used.
-            Defaults to None. This allows the input file to be set a
-            charge independently from the molecule itself.
-        spin_multiplicity: Spin multiplicity of molecule. Defaults to None,
-            which means that the spin multiplicity is set to 1 if the
-            molecule has no unpaired electrons and to 2 if there are
-            unpaired electrons.
-        title: Title for run. Defaults to formula of molecule if None.
-        functional: Functional for run.
-        basis_set: Basis set for run.
-        route_parameters: Additional route parameters as a dict. For example,
-            {'SP':"", "SCF":"Tight"}
-        input_parameters: Additional input parameters for run as a dict. Used
-            for example, in PCM calculations.  E.g., {"EPS":12}
-        link0_parameters: Link0 parameters as a dict. E.g., {"%mem": "1000MW"}
-        dieze_tag: # preceding the route line. E.g. "#p"
-        gen_basis: allows a user-specified basis set to be used in a Gaussian
-            calculation. If this is not None, the attribute ``basis_set`` will
-            be set to "Gen".
     """
 
     # Commonly used regex patterns
@@ -121,6 +98,31 @@ class GaussianInput:
                  functional="HF", basis_set="6-31G(d)", route_parameters=None,
                  input_parameters=None, link0_parameters=None, dieze_tag="#P",
                  gen_basis=None):
+        """
+        Args:
+            mol: Input molecule. If molecule is a single string, it is used as a
+                direct input to the geometry section of the Gaussian input
+                file.
+            charge: Charge of the molecule. If None, charge on molecule is used.
+                Defaults to None. This allows the input file to be set a
+                charge independently from the molecule itself.
+            spin_multiplicity: Spin multiplicity of molecule. Defaults to None,
+                which means that the spin multiplicity is set to 1 if the
+                molecule has no unpaired electrons and to 2 if there are
+                unpaired electrons.
+            title: Title for run. Defaults to formula of molecule if None.
+            functional: Functional for run.
+            basis_set: Basis set for run.
+            route_parameters: Additional route parameters as a dict. For example,
+                {'SP':"", "SCF":"Tight"}
+            input_parameters: Additional input parameters for run as a dict. Used
+                for example, in PCM calculations.  E.g., {"EPS":12}
+            link0_parameters: Link0 parameters as a dict. E.g., {"%mem": "1000MW"}
+            dieze_tag: # preceding the route line. E.g. "#p"
+            gen_basis: allows a user-specified basis set to be used in a Gaussian
+                calculation. If this is not None, the attribute ``basis_set`` will
+                be set to "Gen".
+        """
         self._mol = mol
         self.charge = charge if charge is not None else mol.charge
         nelectrons = - self.charge + mol.charge + mol.nelectrons
@@ -301,7 +303,7 @@ class GaussianInput:
         title = ' '.join(title)
         ind += 1
         toks = re.split(r"[,\s]+", lines[route_index + ind])
-        charge = int(toks[0])
+        charge = int(float(toks[0]))
         spin_mult = int(toks[1])
         coord_lines = []
         spaces = 0
@@ -435,7 +437,7 @@ class GaussianInput:
         output.append("")
         output.append(self.title)
         output.append("")
-        output.append("{} {}".format(self.charge, self.spin_multiplicity))
+        output.append("%d %d" % (self.charge, self.spin_multiplicity))
         if isinstance(self._mol, Molecule):
             if cart_coords is True:
                 output.append(self.get_cart_coords())
@@ -460,6 +462,9 @@ class GaussianInput:
             f.write(self.to_string(cart_coords))
 
     def as_dict(self):
+        """
+        :return: MSONable dict
+        """
         return {"@module": self.__class__.__module__,
                 "@class": self.__class__.__name__,
                 "molecule": self.molecule.as_dict(),
@@ -475,6 +480,10 @@ class GaussianInput:
 
     @classmethod
     def from_dict(cls, d):
+        """
+        :param d: dict
+        :return: GaussianInput
+        """
         return GaussianInput(mol=Molecule.from_dict(d["molecule"]),
                              functional=d["functional"],
                              basis_set=d["basis_set"],
@@ -490,9 +499,6 @@ class GaussianOutput:
     """
     Parser for Gaussian output files.
 
-    Args:
-        filename: Filename of Gaussian output file.
-
     .. note::
 
         Still in early beta.
@@ -683,15 +689,25 @@ class GaussianOutput:
     """
 
     def __init__(self, filename):
+        """
+        Args:
+            filename: Filename of Gaussian output file.
+        """
         self.filename = filename
         self._parse(filename)
 
     @property
     def final_energy(self):
+        """
+        :return: Final energy in Gaussian output.
+        """
         return self.energies[-1]
 
     @property
     def final_structure(self):
+        """
+        :return: Final structure in Gaussian output.
+        """
         return self.structures[-1]
 
     def _parse(self, filename):
@@ -718,7 +734,6 @@ class GaussianOutput:
             r'(Sum of Mulliken )(.*)(charges)\s*=\s*(\D)')
         std_orientation_patt = re.compile(r"Standard orientation")
         input_orientation_patt = re.compile(r"Input orientation")
-        end_patt = re.compile(r"--+")
         orbital_patt = re.compile(r"(Alpha|Beta)\s*\S+\s*eigenvalues --(.*)")
         thermo_patt = re.compile(r"(Zero-point|Thermal) correction(.*)="
                                  r"\s+([\d\.-]+)")
@@ -730,7 +745,6 @@ class GaussianOutput:
 
         freq_on_patt = re.compile(
             r"Harmonic\sfrequencies\s+\(cm\*\*-1\),\sIR\sintensities.*Raman.*")
-        freq_patt = re.compile(r"Frequencies\s--\s+(.*)")
 
         normal_mode_patt = re.compile(
             r"\s+(\d+)\s+(\d+)\s+([0-9\.-]{4,5})\s+([0-9\.-]{4,5}).*")
@@ -762,7 +776,6 @@ class GaussianOutput:
         self.title = None
         self.bond_orders = {}
 
-        coord_txt = []
         read_coord = 0
         read_mulliken = False
         read_eigen = False
@@ -781,6 +794,7 @@ class GaussianOutput:
         parse_bond_order = False
         input_structures = list()
         std_structures = list()
+        geom_orientation = None
 
         with zopen(filename) as f:
             for line in f:
@@ -1065,12 +1079,10 @@ class GaussianOutput:
                         m = scf_patt.search(line)
                         self.energies.append(float(m.group(1)))
                     elif std_orientation_patt.search(line):
-                        coord_txt = []
                         standard_orientation = True
                         geom_orientation = "standard"
                         read_coord = True
                     elif input_orientation_patt.search(line):
-                        coord_txt = []
                         geom_orientation = "input"
                         read_coord = True
                     elif not read_eigen and orbital_patt.search(line):
