@@ -2,6 +2,10 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
+"""
+Classes for reading/manipulating/writing VASP input files. All major VASP input
+files.
+"""
 
 import os
 import re
@@ -39,18 +43,8 @@ from pymatgen.util.io_utils import clean_lines
 from pymatgen.util.typing import PathLike
 from monty.json import MSONable
 
-"""
-Classes for reading/manipulating/writing VASP input files. All major VASP input
-files.
-"""
-
 __author__ = "Shyue Ping Ong, Geoffroy Hautier, Rickard Armiento, Vincent L Chevrier, Stephen Dacek"
 __copyright__ = "Copyright 2011, The Materials Project"
-__version__ = "1.1"
-__maintainer__ = "Shyue Ping Ong"
-__email__ = "shyuep@gmail.com"
-__status__ = "Production"
-__date__ = "Jul 16, 2012"
 
 logger = logging.getLogger(__name__)
 
@@ -61,21 +55,6 @@ class Poscar(MSONable):
     Please note that this current implementation. Most attributes can be set
     directly.
 
-    Args:
-        structure (Structure):  Structure object.
-        comment (str): Optional comment line for POSCAR. Defaults to unit
-            cell formula of structure. Defaults to None.
-        selective_dynamics (Nx3 array): bool values for selective dynamics,
-            where N is number of sites. Defaults to None.
-        true_names (bool): Set to False is the names in the POSCAR are not
-            well-defined and ambiguous. This situation arises commonly in
-            vasp < 5 where the POSCAR sometimes does not contain element
-            symbols. Defaults to True.
-        velocities (Nx3 array): Velocities for the POSCAR. Typically parsed
-            in MD runs or can be used to initialize velocities.
-        predictor_corrector (Nx3 array): Predictor corrector for the POSCAR.
-            Typically parsed in MD runs.
-
     .. attribute:: structure
 
         Associated Structure.
@@ -120,6 +99,22 @@ class Poscar(MSONable):
     def __init__(self, structure, comment=None, selective_dynamics=None,
                  true_names=True, velocities=None, predictor_corrector=None,
                  predictor_corrector_preamble=None):
+        """
+        Args:
+            structure (Structure):  Structure object.
+            comment (str): Optional comment line for POSCAR. Defaults to unit
+                cell formula of structure. Defaults to None.
+            selective_dynamics (Nx3 array): bool values for selective dynamics,
+                where N is number of sites. Defaults to None.
+            true_names (bool): Set to False is the names in the POSCAR are not
+                well-defined and ambiguous. This situation arises commonly in
+                vasp < 5 where the POSCAR sometimes does not contain element
+                symbols. Defaults to True.
+            velocities (Nx3 array): Velocities for the POSCAR. Typically parsed
+                in MD runs or can be used to initialize velocities.
+            predictor_corrector (Nx3 array): Predictor corrector for the POSCAR.
+                Typically parsed in MD runs.
+        """
         if structure.is_ordered:
             site_properties = {}
             if selective_dynamics:
@@ -141,27 +136,33 @@ class Poscar(MSONable):
 
     @property
     def velocities(self):
+        """Velocities in Poscar"""
         return self.structure.site_properties.get("velocities")
 
     @property
     def selective_dynamics(self):
+        """Selective dynamics in Poscar"""
         return self.structure.site_properties.get("selective_dynamics")
 
     @property
     def predictor_corrector(self):
+        """Predictor corrector in Poscar"""
         return self.structure.site_properties.get("predictor_corrector")
 
-    @velocities.setter
+    @velocities.setter  # type: ignore
     def velocities(self, velocities):
+        """Setter for Poscar.velocities"""
         self.structure.add_site_property("velocities", velocities)
 
-    @selective_dynamics.setter
+    @selective_dynamics.setter  # type: ignore
     def selective_dynamics(self, selective_dynamics):
+        """Setter for Poscar.selective_dynamics"""
         self.structure.add_site_property("selective_dynamics",
                                          selective_dynamics)
 
-    @predictor_corrector.setter
+    @predictor_corrector.setter  # type: ignore
     def predictor_corrector(self, predictor_corrector):
+        """Setter for Poscar.predictor_corrector"""
         self.structure.add_site_property("predictor_corrector",
                                          predictor_corrector)
 
@@ -533,6 +534,9 @@ class Poscar(MSONable):
             f.write(self.get_string(**kwargs))
 
     def as_dict(self):
+        """
+        :return: MSONable dict.
+        """
         return {"@module": self.__class__.__module__,
                 "@class": self.__class__.__name__,
                 "structure": self.structure.as_dict(),
@@ -545,6 +549,10 @@ class Poscar(MSONable):
 
     @classmethod
     def from_dict(cls, d):
+        """
+        :param d: Dict representation.
+        :return: Poscar
+        """
         return Poscar(Structure.from_dict(d["structure"]),
                       comment=d["comment"],
                       selective_dynamics=d["selective_dynamics"],
@@ -612,6 +620,9 @@ with open(os.path.join(cwd, "incar_parameters.json")) as incar_params:
 
 
 class BadIncarWarning(UserWarning):
+    """
+    Warning class for bad Incar parameters.
+    """
     pass
 
 
@@ -653,6 +664,9 @@ class Incar(dict, MSONable):
             if isinstance(val, str) else val)
 
     def as_dict(self):
+        """
+        :return: MSONable dict.
+        """
         d = dict(self)
         d["@module"] = self.__class__.__module__
         d["@class"] = self.__class__.__name__
@@ -660,6 +674,10 @@ class Incar(dict, MSONable):
 
     @classmethod
     def from_dict(cls, d):
+        """
+        :param d: Dict representation.
+        :return: Incar
+        """
         if d.get("MAGMOM") and isinstance(d["MAGMOM"][0], dict):
             d["MAGMOM"] = [Magmom.from_dict(m) for m in d["MAGMOM"]]
         return Incar({k: v for k, v in d.items() if k not in ("@module",
@@ -769,10 +787,16 @@ class Incar(dict, MSONable):
             key: INCAR parameter key
             val: Actual value of INCAR parameter.
         """
-        list_keys = tuple([k for k in incar_params.keys() if type(incar_params[k]).__name__ == 'dict'])
-        bool_keys = tuple([k for k in incar_params.keys() if incar_params[k] == 'bool'])
-        float_keys = tuple([k for k in incar_params.keys() if incar_params[k] == 'float'])
-        int_keys = tuple([k for k in incar_params.keys() if incar_params[k] == 'int'])
+        list_keys = ("LDAUU", "LDAUL", "LDAUJ", "MAGMOM", "DIPOL",
+                     "LANGEVIN_GAMMA", "QUAD_EFG", "EINT")
+        bool_keys = ("LDAU", "LWAVE", "LSCALU", "LCHARG", "LPLANE", "LUSE_VDW",
+                     "LHFCALC", "ADDGRID", "LSORBIT", "LNONCOLLINEAR")
+        float_keys = ("EDIFF", "SIGMA", "TIME", "ENCUTFOCK", "HFSCREEN",
+                      "POTIM", "EDIFFG", "AGGAC", "PARAM1", "PARAM2")
+        int_keys = ("NSW", "NBANDS", "NELMIN", "ISIF", "IBRION", "ISPIN",
+                    "ICHARG", "NELM", "ISMEAR", "NPAR", "LDAUPRINT", "LMAXMIX",
+                    "ENCUT", "NSIM", "NKRED", "NUPDOWN", "ISPIND", "LDAUTYPE",
+                    "IVDW")
 
         def smart_int_or_float(numstr):
             if numstr.find(".") != -1 or numstr.lower().find("e") != -1:
@@ -911,15 +935,11 @@ class Incar(dict, MSONable):
                         warnings.warn("%s: Cannot find %s in the list of parameters" % (k, self[k]),
                                       BadIncarWarning, stacklevel=2)
 
-                # If an incar parameter only takes lists, check
-                # if the user provided setting is a list
-                elif type(incar_params[k]).__name__ == 'dict' \
-                        and type(self[k]).__name__ != 'list':
-                    warnings.warn("%s: %s is not a list" % (k, self[k]),
-                                  BadIncarWarning, stacklevel=2)
-
 
 class Kpoints_supported_modes(Enum):
+    """
+    Enum type of all supported modes for Kpoint generation.
+    """
     Automatic = 0
     Gamma = 1
     Monkhorst = 2
@@ -931,7 +951,11 @@ class Kpoints_supported_modes(Enum):
         return self.name
 
     @staticmethod
-    def from_string(s):
+    def from_string(s: str) -> 'Kpoints_supported_modes':
+        """
+        :param s: String
+        :return: Kpoints_supported_modes
+        """
         c = s.lower()[0]
         for m in Kpoints_supported_modes:
             if m.name.lower()[0] == c:
@@ -1008,10 +1032,19 @@ class Kpoints(MSONable):
 
     @property
     def style(self):
+        """
+        :return: Style for kpoint generation. One of Kpoints_supported_modes
+            enum.
+        """
         return self._style
 
     @style.setter
     def style(self, style):
+        """
+        :param style: Style
+        :return: Sets the style for the Kpoints. One of Kpoints_supported_modes
+            enum.
+        """
         if isinstance(style, str):
             style = Kpoints.supported_modes.from_string(style)
 
@@ -1380,7 +1413,9 @@ class Kpoints(MSONable):
         return "\n".join(lines) + "\n"
 
     def as_dict(self):
-        """json friendly dict representation of Kpoints"""
+        """
+        :return: MSONable dict.
+        """
         d = {"comment": self.comment, "nkpoints": self.num_kpts,
              "generation_style": self.style.name, "kpoints": self.kpts,
              "usershift": self.kpts_shift,
@@ -1399,6 +1434,10 @@ class Kpoints(MSONable):
 
     @classmethod
     def from_dict(cls, d):
+        """
+        :param d: Dict representation.
+        :return: Kpoints
+        """
         comment = d.get("comment", "")
         generation_style = d.get("generation_style")
         kpts = d.get("kpoints", [[1, 1, 1]])
@@ -1413,11 +1452,11 @@ class Kpoints(MSONable):
                    tet_connections=d.get("tet_connections"))
 
 
-def parse_string(s):
+def _parse_string(s):
     return "{}".format(s.strip())
 
 
-def parse_bool(s):
+def _parse_bool(s):
     m = re.match(r"^\.?([TFtf])[A-Za-z]*\.?", s)
     if m:
         if m.group(1) == "T" or m.group(1) == "t":
@@ -1427,15 +1466,15 @@ def parse_bool(s):
     raise ValueError(s + " should be a boolean type!")
 
 
-def parse_float(s):
+def _parse_float(s):
     return float(re.search(r"^-?\d*\.?\d*[eE]?-?\d*", s).group(0))
 
 
-def parse_int(s):
+def _parse_int(s):
     return int(re.match(r"^-?[0-9]+", s).group(0))
 
 
-def parse_list(s):
+def _parse_list(s):
     return [float(y) for y in re.split(r"\s+", s.strip()) if not y.isalpha()]
 
 
@@ -1450,10 +1489,6 @@ class PotcarSingle:
     the POTCAR contains the complete untouched data in "data" as a string and
     a dict of keywords.
 
-    Args:
-        data:
-            Complete and single potcar file as a string.
-
     .. attribute:: data
 
         POTCAR data as a string.
@@ -1486,39 +1521,44 @@ class PotcarSingle:
                        "hl": {"name": "Hedin-Lundquist", "class": "LDA"},
                        "wi": {"name": "Wigner Interpoloation", "class": "LDA"}}
 
-    parse_functions = {"LULTRA": parse_bool,
-                       "LUNSCR": parse_bool,
-                       "LCOR": parse_bool,
-                       "LPAW": parse_bool,
-                       "EATOM": parse_float,
-                       "RPACOR": parse_float,
-                       "POMASS": parse_float,
-                       "ZVAL": parse_float,
-                       "RCORE": parse_float,
-                       "RWIGS": parse_float,
-                       "ENMAX": parse_float,
-                       "ENMIN": parse_float,
-                       "EMMIN": parse_float,
-                       "EAUG": parse_float,
-                       "DEXC": parse_float,
-                       "RMAX": parse_float,
-                       "RAUG": parse_float,
-                       "RDEP": parse_float,
-                       "RDEPT": parse_float,
-                       "QCUT": parse_float,
-                       "QGAM": parse_float,
-                       "RCLOC": parse_float,
-                       "IUNSCR": parse_int,
-                       "ICORE": parse_int,
-                       "NDATA": parse_int,
-                       "VRHFIN": parse_string,
-                       "LEXCH": parse_string,
-                       "TITEL": parse_string,
-                       "STEP": parse_list,
-                       "RRKJ": parse_list,
-                       "GGA": parse_list}
+    parse_functions = {"LULTRA": _parse_bool,
+                       "LUNSCR": _parse_bool,
+                       "LCOR": _parse_bool,
+                       "LPAW": _parse_bool,
+                       "EATOM": _parse_float,
+                       "RPACOR": _parse_float,
+                       "POMASS": _parse_float,
+                       "ZVAL": _parse_float,
+                       "RCORE": _parse_float,
+                       "RWIGS": _parse_float,
+                       "ENMAX": _parse_float,
+                       "ENMIN": _parse_float,
+                       "EMMIN": _parse_float,
+                       "EAUG": _parse_float,
+                       "DEXC": _parse_float,
+                       "RMAX": _parse_float,
+                       "RAUG": _parse_float,
+                       "RDEP": _parse_float,
+                       "RDEPT": _parse_float,
+                       "QCUT": _parse_float,
+                       "QGAM": _parse_float,
+                       "RCLOC": _parse_float,
+                       "IUNSCR": _parse_int,
+                       "ICORE": _parse_int,
+                       "NDATA": _parse_int,
+                       "VRHFIN": _parse_string,
+                       "LEXCH": _parse_string,
+                       "TITEL": _parse_string,
+                       "STEP": _parse_list,
+                       "RRKJ": _parse_list,
+                       "GGA": _parse_list}
 
     def __init__(self, data):
+        """
+        Args:
+            data:
+                Complete and single potcar file as a string.
+        """
         self.data = data  # raw POTCAR as a string
 
         # Vasp parses header in vasprun.xml and this differs from the titel
@@ -1584,7 +1624,7 @@ class PotcarSingle:
         if rrkj_kinetic_energy_string:
             for line in rrkj_kinetic_energy_string.group(1).splitlines():
                 if "=" not in line:
-                    rrkj_array += parse_list(line.strip('\n'))
+                    rrkj_array += _parse_list(line.strip('\n'))
             if rrkj_array:
                 PSCTR['RRKJ'] = tuple(rrkj_array)
 
@@ -1597,6 +1637,9 @@ class PotcarSingle:
 
     @property
     def electron_configuration(self):
+        """
+        :return: Electronic configuration of the PotcarSingle.
+        """
         if not self.nelectrons.is_integer():
             warnings.warn("POTCAR has non-integer charge, "
                           "electron configuration not well-defined.")
@@ -1611,12 +1654,22 @@ class PotcarSingle:
             nelect -= e[-1]
         return config
 
-    def write_file(self, filename):
+    def write_file(self, filename: str) -> None:
+        """
+        Writes PotcarSingle to a file.
+        :param filename: Filename
+        """
         with zopen(filename, "wt") as f:
             f.write(self.__str__())
 
     @staticmethod
-    def from_file(filename):
+    def from_file(filename: str) -> 'PotcarSingle':
+        """
+        Reads PotcarSingle from file.
+
+        :param filename: Filename.
+        :return: PotcarSingle.
+        """
         try:
             with zopen(filename, "rt") as f:
                 return PotcarSingle(f.read())
@@ -1629,7 +1682,14 @@ class PotcarSingle:
                 return PotcarSingle(f.read())
 
     @staticmethod
-    def from_symbol_and_functional(symbol, functional=None):
+    def from_symbol_and_functional(symbol: str, functional: str = None):
+        """
+        Makes a PotcarSingle from a symbol and functional.
+
+        :param symbol: Symbol, e.g., Li_sv
+        :param functional: E.g., PBE
+        :return: PotcarSingle
+        """
         if functional is None:
             functional = SETTINGS.get("PMG_DEFAULT_FUNCTIONAL", "PBE")
         funcdir = PotcarSingle.functional_dir[functional]
@@ -1649,8 +1709,7 @@ class PotcarSingle:
             if os.path.exists(p):
                 return PotcarSingle.from_file(p)
         raise IOError("You do not have the right POTCAR with functional " +
-                      "{} and label {} in your VASP_PSP_DIR".format(functional,
-                                                                    symbol))
+                      "{} and label {} in your VASP_PSP_DIR".format(functional, symbol))
 
     @property
     def symbol(self):
@@ -1675,7 +1734,7 @@ class PotcarSingle:
             return Element(self.symbol.split("_")[0]).symbol
 
     @property
-    def atomic_no(self):
+    def atomic_no(self) -> int:
         """
         Attempt to return the atomic number based on the VRHFIN keyword.
         """
@@ -1683,10 +1742,16 @@ class PotcarSingle:
 
     @property
     def nelectrons(self):
+        """
+        :return: Number of electrons
+        """
         return self.zval
 
     @property
-    def potential_type(self):
+    def potential_type(self) -> str:
+        """
+        :return: Type of PSP. E.g., US, PAW, etc.
+        """
         if self.lultra:
             return "US"
         elif self.lpaw:
@@ -1696,13 +1761,24 @@ class PotcarSingle:
 
     @property
     def functional(self):
+        """
+        :return: Functional associated with PotcarSingle.
+        """
         return self.functional_tags.get(self.LEXCH.lower(), {}).get('name')
 
     @property
     def functional_class(self):
+        """
+        :return: Functional class associated with PotcarSingle.
+        """
         return self.functional_tags.get(self.LEXCH.lower(), {}).get('class')
 
     def get_potcar_hash(self):
+        """
+        Computes a hash for the PotcarSingle.
+
+        :return: Hash value.
+        """
         hash_str = ""
         for k, v in self.PSCTR.items():
             hash_str += "{}".format(k)
@@ -1749,25 +1825,26 @@ class Potcar(list, MSONable):
     """
     Object for reading and writing POTCAR files for calculations. Consists of a
     list of PotcarSingle.
-
-    Args:
-        symbols ([str]): Element symbols for POTCAR. This should correspond
-            to the symbols used by VASP. E.g., "Mg", "Fe_pv", etc.
-        functional (str): Functional used. To know what functional options
-            there are, use Potcar.FUNCTIONAL_CHOICES. Note that VASP has
-            different versions of the same functional. By default, the old
-            PBE functional is used. If you want the newer ones, use PBE_52 or
-            PBE_54. Note that if you intend to compare your results with the
-            Materials Project, you should use the default setting. You can also
-            override the default by setting PMG_DEFAULT_FUNCTIONAL in your
-            .pmgrc.yaml.
-        sym_potcar_map (dict): Allows a user to specify a specific element
-            symbol to raw POTCAR mapping.
     """
 
     FUNCTIONAL_CHOICES = list(PotcarSingle.functional_dir.keys())
 
     def __init__(self, symbols=None, functional=None, sym_potcar_map=None):
+        """
+        Args:
+            symbols ([str]): Element symbols for POTCAR. This should correspond
+                to the symbols used by VASP. E.g., "Mg", "Fe_pv", etc.
+            functional (str): Functional used. To know what functional options
+                there are, use Potcar.FUNCTIONAL_CHOICES. Note that VASP has
+                different versions of the same functional. By default, the old
+                PBE functional is used. If you want the newer ones, use PBE_52 or
+                PBE_54. Note that if you intend to compare your results with the
+                Materials Project, you should use the default setting. You can also
+                override the default by setting PMG_DEFAULT_FUNCTIONAL in your
+                .pmgrc.yaml.
+            sym_potcar_map (dict): Allows a user to specify a specific element
+                symbol to raw POTCAR mapping.
+        """
         if functional is None:
             functional = SETTINGS.get("PMG_DEFAULT_FUNCTIONAL", "PBE")
         super().__init__()
@@ -1776,16 +1853,29 @@ class Potcar(list, MSONable):
             self.set_symbols(symbols, functional, sym_potcar_map)
 
     def as_dict(self):
+        """
+        :return: MSONable dict representation
+        """
         return {"functional": self.functional, "symbols": self.symbols,
                 "@module": self.__class__.__module__,
                 "@class": self.__class__.__name__}
 
     @classmethod
     def from_dict(cls, d):
+        """
+        :param d: Dict representation
+        :return: Potcar
+        """
         return Potcar(symbols=d["symbols"], functional=d["functional"])
 
     @staticmethod
-    def from_file(filename):
+    def from_file(filename: str):
+        """
+        Reads Potcar from file.
+
+        :param filename: Filename
+        :return: Potcar
+        """
         try:
             with zopen(filename, "rt") as f:
                 fdata = f.read()
@@ -1871,19 +1961,20 @@ class Potcar(list, MSONable):
 class VaspInput(dict, MSONable):
     """
     Class to contain a set of vasp input objects corresponding to a run.
-
-    Args:
-        incar: Incar object.
-        kpoints: Kpoints object.
-        poscar: Poscar object.
-        potcar: Potcar object.
-        optional_files: Other input files supplied as a dict of {
-            filename: object}. The object should follow standard pymatgen
-            conventions in implementing a as_dict() and from_dict method.
     """
 
     def __init__(self, incar, kpoints, poscar, potcar, optional_files=None,
                  **kwargs):
+        """
+        Args:
+            incar: Incar object.
+            kpoints: Kpoints object.
+            poscar: Poscar object.
+            potcar: Potcar object.
+            optional_files: Other input files supplied as a dict of {
+                filename: object}. The object should follow standard pymatgen
+                conventions in implementing a as_dict() and from_dict method.
+        """
         super().__init__(**kwargs)
         self.update({'INCAR': incar,
                      'KPOINTS': kpoints,
@@ -1901,6 +1992,9 @@ class VaspInput(dict, MSONable):
         return "\n".join(output)
 
     def as_dict(self):
+        """
+        :return: MSONable dict.
+        """
         d = {k: v.as_dict() for k, v in self.items()}
         d["@module"] = self.__class__.__module__
         d["@class"] = self.__class__.__name__
@@ -1908,6 +2002,10 @@ class VaspInput(dict, MSONable):
 
     @classmethod
     def from_dict(cls, d):
+        """
+        :param d: Dict representation.
+        :return: VaspInput
+        """
         dec = MontyDecoder()
         sub_d = {"optional_files": {}}
         for k, v in d.items():
