@@ -34,7 +34,7 @@ class PBarSafe:
 
 try:
     # noinspection PyUnresolvedReferences
-    if get_ipython().__class__.__name__ == 'ZMQInteractiveShell':
+    if get_ipython().__class__.__name__ == 'ZMQInteractiveShell':  # type: ignore
         from tqdm import tqdm_notebook as PBar
     else:  # likely 'TerminalInteractiveShell'
         from tqdm import tqdm as PBar
